==> ng2-homeworks-1.0.22.tgz: package/README.md <==
# HOMEWORKS for Angular 2

[![npm version](https://badge.fury.io/js/ng2-homeworks.svg)](https://badge.fury.io/js/ng2-homeworks)
[![Bower version](https://badge.fury.io/bo/ng2-homeworks.svg)](https://badge.fury.io/bo/ng2-homeworks)
<br />
[![Dependencies Status](https://david-dm.org/IGAWorksDev/ng2-homeworks.svg)](https://david-dm.org/IGAWorksDev/ng2-homeworks)
[![Dev Dependencies Status](https://david-dm.org/IGAWorksDev/ng2-homeworks/dev-status.svg)](https://david-dm.org/IGAWorksDev/ng2-homeworks?type=dev)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

The HomeWorks framework fully supports angular components.

![HomeWorks Framework](https://s3.ap-northeast-2.amazonaws.com/homeworks.igaworks.com/main/src/images/homeworks_cover_angular2_v1.png?v=1)

```plaintext
This markdown document has not been completed yet.
You can take part in editing this document using GitHub fork feature.
```

## Overview

This project is part of [Homeworks](https://github.com/IGAWorksDev/homeworks) project,

So you would be better to install the core of Homeworks before you're following this instrduction.

- [**See live demo site** (http://homeworks.igaworks.com)](http://homeworks.igaworks.com).
- [See Github of this project](https://www.github.com/IGAWorksDev/ng2-homeworks).
- [See Homeworks project on GitHub](https://github.com/IGAWorksDev/homeworks)

## Installation

- [Quick Start](docs/installation/quickstart.md)

## Components

- [Checkbox](docs/components/checkbox.md)
- [Dropdown](docs/components/dropdown.md)
- [Input](docs/components/input.md)
- [Ripple](docs/components/ripple.md)
- [Spinner](docs/components/spinner.md)
- [Step](docs/components/step.md)
- [Tab](docs/components/tab.md)
- [Toggle](docs/components/toggle.md)

## Contribution

- Core
- Model

==> ng2-homeworks-1.0.50.tgz: package/README.md <==
# HOMEWORKS for Angular 2

[![npm version](https://badge.fury.io/js/ng2-homeworks.svg)](https://badge.fury.io/js/ng2-homeworks)
[![Bower version](https://badge.fury.io/bo/ng2-homeworks.svg)](https://badge.fury.io/bo/ng2-homeworks)
<br />
[![Dependencies Status](https://david-dm.org/IGAWorksDev/ng2-homeworks.svg)](https://david-dm.org/IGAWorksDev/ng2-homeworks)
[![Dev Dependencies Status](https://david-dm.org/IGAWorksDev/ng2-homeworks/dev-status.svg)](https://david-dm.org/IGAWorksDev/ng2-homeworks?type=dev)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

![HomeWorks Framework](https://s3.ap-northeast-2.amazonaws.com/homeworks.igaworks.com/main/src/images/homeworks_cover_angular2_v1.png?v=1)

```plaintext
This markdown document has not been completed yet.
You can take part in editing this document using GitHub fork feature.
```

## Overview

This project is part of [homeworks](https://github.com/IGAWorksDev/homeworks) project,

So you would be better to install the core of homeworks before you're following this instroduction.

- [**See live demo site** (http://homeworks.igaworks.com)](http://homeworks.igaworks.com).
- [See Github of this project](https://www.github.com/IGAWorksDev/ng2-homeworks).
- [See homeworks project on the GitHub](https://github.com/IGAWorksDev/homeworks)

## Installation

- [Quick Start](docs/installation/quickstart.md)

## Components

- [Checkbox](docs/components/checkbox.md)
- [Dropdown](docs/components/dropdown.md)
- [Input](docs/components/input.md)
- [Ripple](docs/components/ripple.md)
- [Spinner](docs/components/spinner.md)
- [Step](docs/components/step.md)
- [Tab](docs/components/tab.md)
- [Toggle](docs/components/toggle.md)

## Contribution Documentation

- Core
- Model
